==> jacktrip_2.4.1+ds.orig.tar.xz: jacktrip-2.4.1/src/vs/vsQuickView.cpp <==
//*****************************************************************
/*
  JackTrip: A System for High-Quality Audio Network Performance
  over the Internet

  Copyright (c) 2022-2024 JackTrip Labs, Inc.

  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation
  files (the "Software"), to deal in the Software without
  restriction, including without limitation the rights to use,
  copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be
  included in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
  OTHER DEALINGS IN THE SOFTWARE.
*/
//*****************************************************************

/**
 * \file vsQuickView.cpp
 * \author Aaron Wyatt
 * \date March 2022
 */

#include "vsQuickView.h"

#include <QDesktopServices>
#include <iostream>

VsQuickView::VsQuickView(QWindow* parent) : QQuickView(parent)
{
#ifdef Q_OS_MACOS
    auto* quit = new QAction("&Quit", this);

    QMenuBar* menuBar = new QMenuBar(nullptr);
    QMenu* appName    = menuBar->addMenu("&JackTrip");
    appName->addAction(quit);

    connect(quit, &QAction::triggered, this, &VsQuickView::closeWindow);
#endif
}

bool VsQuickView::event(QEvent* event)
{
    if (event->type() == QEvent::Close || event->type() == QEvent::Quit) {
        emit windowClose();
        event->ignore();
    }
    return QQuickView::event(event);
}

void VsQuickView::closeWindow()
{
    emit windowClose();
}

==> jacktrip_2.5.1+ds.orig.tar.xz: jacktrip-2.5.1/src/vs/vsQuickView.cpp <==
//*****************************************************************
/*
  JackTrip: A System for High-Quality Audio Network Performance
  over the Internet

  Copyright (c) 2022-2024 JackTrip Labs, Inc.

  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation
  files (the "Software"), to deal in the Software without
  restriction, including without limitation the rights to use,
  copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be
  included in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
  OTHER DEALINGS IN THE SOFTWARE.
*/
//*****************************************************************

/**
 * \file vsQuickView.cpp
 * \author Aaron Wyatt
 * \date March 2022
 */

#include "vsQuickView.h"

#include <QDesktopServices>
#include <iostream>

VsQuickView::VsQuickView(QWindow* parent) : QQuickView(parent)
{
#ifdef Q_OS_MACOS
    auto* quit = new QAction("&Quit", this);

    QMenuBar* menuBar = new QMenuBar(nullptr);
    QMenu* appName    = menuBar->addMenu("&JackTrip");
    appName->addAction(quit);

    connect(quit, &QAction::triggered, this, &VsQuickView::closeWindow);
#endif
}

bool VsQuickView::event(QEvent* event)
{
    if (event->type() == QEvent::FocusIn) {
        emit focusGained();
    } else if (event->type() == QEvent::FocusOut) {
        emit focusLost();
    } else if (event->type() == QEvent::Close || event->type() == QEvent::Quit) {
        emit windowClose();
        event->ignore();
    }
    return QQuickView::event(event);
}

void VsQuickView::closeWindow()
{
    emit windowClose();
}
